@@ -1,7 +1,9 @@
-from typing import Dict
+from typing import Dict, Union
+
+from .reference import Reference
 
 
-Callback = Dict[str, "PathItem"]
+Callback = Dict[str, Union["PathItem", Reference]]
 """
 A map of possible out-of band callbacks related to the parent operation.
 Each value in the map is a [Path Item Object](#pathItemObject)
