@@ -1,6 +1,6 @@
 from typing import Optional
 
-from pydantic import AnyUrl, BaseModel
+from pydantic import AnyUrl, BaseModel, Extra
 
 
 class ExternalDocumentation(BaseModel):
@@ -15,8 +15,9 @@ class ExternalDocumentation(BaseModel):
     url: AnyUrl = ...
     """
     **REQUIRED**. The URL for the target documentation.
-    Value MUST be in the format of a URL.
+    Value MUST be in the form of a URL.
     """
 
     class Config:
+        extra = Extra.ignore
         schema_extra = {"examples": [{"description": "Find more info here", "url": "https://example.com"}]}
