@@ -8,7 +8,7 @@ Paths = Dict[str, PathItem]
 Holds the relative paths to the individual endpoints and their operations.
 The path is appended to the URL from the [`Server Object`](#serverObject) in order to construct the full URL.
 
-The Paths MAY be empty, due to [ACL constraints](#securityFiltering).
+The Paths MAY be empty, due to [Access Control List (ACL) constraints](#securityFiltering).
 """
 
 """Patterned Fields"""
